@@ -117,6 +117,15 @@ export const registerBbyButtons = () => {
       'add-video-player-step',
       'ipybbycell'
     ),
+    Jupyter.keyboard_manager.actions.register(
+      {
+        help: '添加「音频」',
+        icon: 'fa-file-audio-o',
+        handler: addAudioStep,
+      },
+      'add-audio-player-step',
+      'ipybbycell'
+    ),
   ]);
 
   Jupyter.toolbar.add_buttons_group([
@@ -452,6 +461,20 @@ const addVideoPlayerStep = function () {
 `);
 };
 
+const addAudioStep = function () {
+  insertCodeInCurrentMarkdownCell(`
+<!-- ---------------------------------------- -->
+<!-- /////////// 音频播放器 Begin /////////// -->
+<!-- ---------------------------------------- -->
+<audio controls>
+  <source src="【此处填入音频链接】" />
+</audio>
+<!-- ---------------------------------------- -->
+<!-- /////////// 音频播放器 End //////////// -->
+<!-- ---------------------------------------- -->
+`);
+};
+
 
 const addFileCell = function () {
   insertCodeCellBelow(`#platform-lock-hidden
